.. py:currentmodule:: drdmannturb


Loss Function Evaluation
========================

Parameters for the loss function are set in :py:class:`LossParameters`.

.. autoclass:: drdmannturb.LossAggregator
    :members:

